@@ -2,4 +2,6 @@
 
 set -eufo pipefail
 
-( cd /chezmoi && go test ./... )
+cd /chezmoi
+
+go test ./...
