@@ -388,8 +388,8 @@ func newConfig(options ...configOption) (*Config, error) {
 			recursive: true,
 		},
 		upgrade: upgradeCmdConfig{
-			owner: "twpayne",
-			repo:  "chezmoi",
+			owner: gitHubOwner,
+			repo:  gitHubRepo,
 		},
 		verify: verifyCmdConfig{
 			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
@@ -1059,34 +1059,22 @@ func (c *Config) diffFile(
 
 // editor returns the path to the user's editor and any extra arguments.
 func (c *Config) editor(args []string) (string, []string) {
-	// If the user has set and edit command then use it.
-	if c.Edit.Command != "" {
-		return c.Edit.Command, append(c.Edit.Args, args...)
+	editCommand := c.Edit.Command
+	editArgs := c.Edit.Args
+
+	// If the user has set an edit command then use it.
+	if editCommand != "" {
+		return editCommand, append(editArgs, args...)
 	}
 
 	// Prefer $VISUAL over $EDITOR and fallback to the OS's default editor.
-	editor := firstNonEmptyString(
+	editCommand = firstNonEmptyString(
 		os.Getenv("VISUAL"),
 		os.Getenv("EDITOR"),
 		defaultEditor,
 	)
 
-	// If editor is found, return it.
-	if path, err := exec.LookPath(editor); err == nil {
-		return path, args
-	}
-
-	// Otherwise, if editor contains spaces, then assume that the first word is
-	// the editor and the rest are arguments.
-	components := whitespaceRx.Split(editor, -1)
-	if len(components) > 1 {
-		if path, err := exec.LookPath(components[0]); err == nil {
-			return path, append(components[1:], args...)
-		}
-	}
-
-	// Fallback to editor only.
-	return editor, args
+	return parseCommand(editCommand, append(editArgs, args...))
 }
 
 // errorf writes an error to stderr.
@@ -1488,8 +1476,9 @@ func (c *Config) pageOutputString(output, cmdPager string) error {
 	// it directly.
 	var pagerCmd *exec.Cmd
 	if strings.IndexFunc(pager, unicode.IsSpace) != -1 {
-		shell, _ := shell.CurrentUserShell()
-		pagerCmd = exec.Command(shell, "-c", pager)
+		shellCommand, _ := shell.CurrentUserShell()
+		shellCommand, shellArgs := parseCommand(shellCommand, []string{"-c", pager})
+		pagerCmd = exec.Command(shellCommand, shellArgs...)
 	} else {
 		pagerCmd = exec.Command(pager)
 	}
@@ -1656,12 +1645,24 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 	}
 
 	// Create the source directory if needed.
-	if boolAnnotation(cmd, requiresSourceDirectory) {
+	if boolAnnotation(cmd, createSourceDirectoryIfNeeded) {
 		if err := chezmoi.MkdirAll(c.baseSystem, c.SourceDirAbsPath, 0o777); err != nil {
 			return err
 		}
 	}
 
+	// Verify that the source directory exists and is a directory, if needed.
+	if boolAnnotation(cmd, requiresSourceDirectory) {
+		switch fileInfo, err := c.baseSystem.Stat(c.SourceDirAbsPath); {
+		case err == nil && fileInfo.IsDir():
+			// Do nothing.
+		case err == nil:
+			return fmt.Errorf("%s: not a directory", c.SourceDirAbsPath)
+		case err != nil:
+			return err
+		}
+	}
+
 	// Create the runtime directory if needed.
 	if boolAnnotation(cmd, runsCommands) {
 		if runtime.GOOS == "linux" && c.bds.RuntimeDir != "" {
@@ -2080,6 +2081,25 @@ func (c *Config) writeOutputString(data string) error {
 	return c.writeOutput([]byte(data))
 }
 
+func parseCommand(command string, args []string) (string, []string) {
+	// If command is found, then return it.
+	if path, err := exec.LookPath(command); err == nil {
+		return path, args
+	}
+
+	// Otherwise, if the command contains spaces, then assume that the first word
+	// is the editor and the rest are arguments.
+	components := whitespaceRx.Split(command, -1)
+	if len(components) > 1 {
+		if path, err := exec.LookPath(components[0]); err == nil {
+			return path, append(components[1:], args...)
+		}
+	}
+
+	// Fallback to the command only.
+	return command, args
+}
+
 // withVersionInfo sets the version information.
 func withVersionInfo(versionInfo VersionInfo) configOption {
 	return func(c *Config) error {
