@@ -2,9 +2,11 @@ package cmd
 
 import (
 	"bytes"
+	"context"
 	"errors"
 	"fmt"
 	"io/fs"
+	"net/http"
 	"os"
 	"os/exec"
 	"regexp"
@@ -50,6 +52,13 @@ var checkResultStr = map[checkResult]string{
 	checkResultFailed:  "failed",
 }
 
+// An argsCheck checks that arguments for a binary.
+type argsCheck struct {
+	name    string
+	command string
+	args    []string
+}
+
 // A binaryCheck checks that a binary called name is installed and optionally at
 // least version minVersion.
 type binaryCheck struct {
@@ -90,6 +99,15 @@ type fileCheck struct {
 // A goVersionCheck checks the Go version.
 type goVersionCheck struct{}
 
+// A latestVersionCheck checks the latest version.
+type latestVersionCheck struct {
+	httpClient    *http.Client
+	httpClientErr error
+	owner         string
+	repo          string
+	version       semver.Version
+}
+
 // An osArchCheck checks that runtime.GOOS and runtime.GOARCH are supported.
 type osArchCheck struct{}
 
@@ -133,13 +151,23 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
-	shell, _ := shell.CurrentUserShell()
-	editCommand, _ := c.editor(nil)
+	httpClient, httpClientErr := c.getHTTPClient()
+	shellCommand, _ := shell.CurrentUserShell()
+	shellCommand, shellArgs := parseCommand(shellCommand, nil)
+	cdCommand, cdArgs := c.cdCommand()
+	editCommand, editArgs := c.editor(nil)
 	checks := []check{
 		&versionCheck{
 			versionInfo: c.versionInfo,
 			versionStr:  c.versionStr,
 		},
+		&latestVersionCheck{
+			httpClient:    httpClient,
+			httpClientErr: httpClientErr,
+			owner:         gitHubOwner,
+			repo:          gitHubRepo,
+			version:       c.version,
+		},
 		osArchCheck{},
 		unameCheck{},
 		systeminfoCheck{},
@@ -167,17 +195,44 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			dirname: c.DestDirAbsPath,
 		},
 		&binaryCheck{
-			name:       "shell",
-			binaryname: shell,
+			name:       "shell-command",
+			binaryname: shellCommand,
 			ifNotSet:   checkResultError,
 			ifNotExist: checkResultError,
 		},
+		&argsCheck{
+			name:    "shell-args",
+			command: shellCommand,
+			args:    shellArgs,
+		},
+		&binaryCheck{
+			name:       "cd-command",
+			binaryname: cdCommand,
+			ifNotSet:   checkResultError,
+			ifNotExist: checkResultError,
+		},
+		&argsCheck{
+			name:    "cd-args",
+			command: cdCommand,
+			args:    cdArgs,
+		},
 		&binaryCheck{
 			name:       "edit-command",
 			binaryname: editCommand,
 			ifNotSet:   checkResultWarning,
 			ifNotExist: checkResultWarning,
 		},
+		&argsCheck{
+			name:    "edit-args",
+			command: editCommand,
+			args:    editArgs,
+		},
+		&binaryCheck{
+			name:       "diff-command",
+			binaryname: c.Diff.Command,
+			ifNotSet:   checkResultInfo,
+			ifNotExist: checkResultWarning,
+		},
 		umaskCheck{},
 		&binaryCheck{
 			name:        "git-command",
@@ -315,6 +370,14 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 	return nil
 }
 
+func (c *argsCheck) Name() string {
+	return c.name
+}
+
+func (c *argsCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
+	return checkResultOK, shellQuoteCommand(c.command, c.args)
+}
+
 func (c *binaryCheck) Name() string {
 	return c.name
 }
@@ -465,6 +528,35 @@ func (goVersionCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath)
 	return checkResultOK, fmt.Sprintf("%s (%s)", runtime.Version(), runtime.Compiler)
 }
 
+func (c *latestVersionCheck) Name() string {
+	return "latest-version"
+}
+
+func (c *latestVersionCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
+	if c.httpClientErr != nil {
+		return checkResultError, c.httpClientErr.Error()
+	}
+
+	ctx := context.Background()
+
+	gitHubClient := chezmoi.NewGitHubClient(ctx, c.httpClient)
+	rr, _, err := gitHubClient.Repositories.GetLatestRelease(ctx, c.owner, c.repo)
+	if err != nil {
+		return checkResultError, err.Error()
+	}
+
+	version, err := semver.NewVersion(strings.TrimPrefix(rr.GetName(), "v"))
+	if err != nil {
+		return checkResultError, err.Error()
+	}
+
+	checkResult := checkResultOK
+	if c.version.LessThan(*version) {
+		checkResult = checkResultWarning
+	}
+	return checkResult, "v" + version.String()
+}
+
 func (osArchCheck) Name() string {
 	return "os-arch"
 }
